@@ -1,7 +1,9 @@
 from .actor import Actor
+from .asyncio_monitor import AsyncioMonitor
 from .automator import Automator
 from .camera_projector import CameraProjector
 from .detector import Detector
+from .garbage_collector import GarbageCollector
 from .lizard import Lizard
 from .network_monitor import NetworkMonitor, NetworkStats
 from .odometer import Odometer
