@@ -19,8 +19,8 @@ class UsbCameraCapture(Actor):
         await super().step()
         await self.update_device_list()
         for uid, camera in self.world.usb_cameras.items():
-            if not camera.capture:
-                return
+            if not camera.capture or not camera.connected:
+                continue
             bytes = await rosys.run.io_bound(self.capture_image, uid)
             camera.images.append(Image(camera_id=uid, data=bytes, time=self.world.time, size=camera.resolution))
         self.purge_old_images()
@@ -39,6 +39,8 @@ class UsbCameraCapture(Actor):
             return
         self.last_scan = self.world.time
         output = await rosys.run.sh(['v4l2-ctl', '--list-devices'])
+        for c in self.world.usb_cameras.values():
+            c.connected = False
         for infos in output.split('\n\n'):
             if 'Cannot open device' in infos:
                 continue
@@ -47,16 +49,17 @@ class UsbCameraCapture(Actor):
                 continue
             uid = match.group(1)
             if uid not in self.world.usb_cameras:
-                self.world.usb_cameras[uid] = UsbCamera(id=uid)
+                self.world.usb_cameras[uid] = UsbCamera(id=uid, connected=True)
                 self.log.info(f'adding camera {uid}')
                 await event.call(event.Id.NEW_CAMERA, self.world.usb_cameras[uid])
+            self.world.usb_cameras[uid].connected = True
             lines = infos.splitlines()
             num = int(lines[1].strip().lstrip('/dev/video'))
             if uid not in self.devices:
                 device = self.get_capture_device(num)
                 if device is None:
                     if uid in self.world.usb_cameras:
-                        del self.world.usb_cameras[uid]
+                        self.world.usb_cameras[uid].connected = False
                 else:
                     self.devices[uid] = device
             if uid in self.devices:
