@@ -1,5 +1,5 @@
-import asyncio
 from typing import Optional
+from .. import sleep
 from ..communication import Communication
 from ..world import Velocity, World
 from . import CommunicatingHardware
@@ -9,7 +9,7 @@ class RobotBrain(CommunicatingHardware):
 
     def __init__(self, world: World, communication: Communication):
         super().__init__(world, communication)
-        self.waiting_list = set()
+        self.waiting_list: dict[str, Optional[str]] = {}
 
     async def configure(self, filepath: str = 'lizard.txt'):
         await super().configure()
@@ -55,34 +55,38 @@ class RobotBrain(CommunicatingHardware):
                 continue
             first = words.pop(0)
             if first in self.waiting_list:
-                self.waiting_list.remove(first)
+                self.waiting_list[first] = line
                 continue
-            if first not in ['core', '!"core']:
-                continue
-            millis = float(words.pop(0))
-            if self.world.robot.clock_offset is None:
-                continue
-            self.world.robot.hardware_time = millis / 1000 + self.world.robot.clock_offset
-            self.parse(words)
+            if first == 'core':
+                millis = float(words.pop(0))
+                if self.world.robot.clock_offset is None:
+                    continue
+                self.world.robot.hardware_time = millis / 1000 + self.world.robot.clock_offset
+                self.parse_core(words)
+            self.parse_line(line)
         if millis is not None:
             self.world.robot.clock_offset = self.world.time - millis / 1000
 
-    def parse(self, words: list[str]):
+    def parse_core(self, words: list[str]):
         self.world.robot.odometry.append(Velocity(
             linear=float(words.pop(0)),
             angular=float(words.pop(0)),
             time=self.world.robot.hardware_time,
         ))
 
+    def parse_line(self, line: str):
+        pass
+
     async def send(self, msg: str):
         await self.communication.send_async(self.augment(msg))
 
-    async def send_and_await(self, msg: str, ack: str):
-        ack_str = f'!""{ack}"'
-        self.waiting_list.add(ack_str)
+    async def send_and_await(self, msg: str, ack: str, *, timeout: float = float('inf')) -> Optional[str]:
+        self.waiting_list[ack] = None
         await self.send(msg)
-        while ack_str in self.waiting_list:
-            await asyncio.sleep(0)
+        t0 = self.world.time
+        while self.waiting_list.get(ack) is None and self.world.time < t0 + timeout:
+            await sleep(0.1)
+        return self.waiting_list.pop(ack) if ack in self.waiting_list else None
 
     @staticmethod
     def augment(line: str) -> str:
