@@ -1,3 +1,4 @@
+from typing import Awaitable, Optional
 from nicegui.ui import Ui
 from .. import Runtime
 
@@ -6,10 +7,10 @@ class AutomationControls:
     ui: Ui
     runtime: Runtime
 
-    def __init__(self) -> None:
+    def __init__(self, default_automation: Optional[Awaitable] = None) -> None:
 
         def start():
-            self.runtime.automator.start()
+            self.runtime.automator.start(default_automation())
 
         def pause():
             self.runtime.automator.pause(because='pause button was pressed')
@@ -29,6 +30,6 @@ class AutomationControls:
             play_button.visible = self.runtime.automator.is_stopped
             pause_button.visible = self.runtime.automator.is_running
             resume_button.visible = self.runtime.automator.is_paused
-            play_button.view.disable = self.runtime.automator.default_automation is None
+            play_button.view.disable = default_automation is None
             stop_button.view.disable = self.runtime.automator.is_stopped
         self.ui.timer(0.1, refresh)
