@@ -2,8 +2,9 @@ from nicegui.ui import Ui
 import logging
 import yappi
 from tabulate import tabulate
-import asyncio
 import time
+from .. import sleep
+from ..profiling import profile
 
 log = logging.getLogger('rosys.profiler')
 
@@ -15,14 +16,16 @@ def create_profiler(ui: Ui):
         profile_button.props(replace='icon=stop')
         yappi.clear_stats()
         yappi.start()
+        profile.start()
         t = time.time()
         while yappi.is_running() and time.time() < t + duration:
-            await asyncio.sleep(0.1)
+            await sleep(0.1)
         stop()
 
     def stop():
         ui.notify('stop profiling')
         profile_button.props(replace='icon=play_arrow')
+        profile.stop(print=False)
         yappi.stop()
         table = [
             [str(v) for v in [stat.full_name, stat.ttot, stat.tsub, stat.tavg, stat.ncall]]
@@ -36,6 +39,7 @@ def create_profiler(ui: Ui):
         )
         print(output, flush=True)
         yappi.get_thread_stats().print_all()
+        profile.print()
 
     async def toggle() -> bool:
         if yappi.is_running():
